@@ -29,8 +29,6 @@
 #include "absl/status/status.h"
 #include "absl/status/statusor.h"
 #include "src/core/channelz/channelz.h"
-#include "src/core/ext/transport/chttp2/transport/hpack_encoder.h"
-#include "src/core/ext/transport/chttp2/transport/hpack_parser.h"
 #include "src/core/handshaker/handshaker.h"
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/iomgr/closure.h"
@@ -46,6 +44,11 @@
 #include "src/core/util/sync.h"
 #include "src/core/util/time.h"
 
+// Channel arg: integer number of data connections to specify
+// Defaults to 1 if not set
+#define GRPC_ARG_CHAOTIC_GOOD_DATA_CONNECTIONS \
+  "grpc.chaotic_good.data_connections"
+
 namespace grpc_core {
 namespace chaotic_good {
 class ChaoticGoodServerListener final : public Server::ListenerInterface {
@@ -111,7 +114,7 @@ class ChaoticGoodServerListener final : public Server::ListenerInterface {
 
    private:
     void Done();
-    void NewConnectionID();
+    void NewConnectionIDs(size_t count);
     RefCountedPtr<Arena> arena_ = SimpleArenaAllocator()->MakeArena();
     const RefCountedPtr<ChaoticGoodServerListener> listener_;
     RefCountedPtr<HandshakingState> handshaking_state_;
@@ -119,11 +122,9 @@ class ChaoticGoodServerListener final : public Server::ListenerInterface {
     ActivityPtr receive_settings_activity_ ABSL_GUARDED_BY(mu_);
     bool orphaned_ ABSL_GUARDED_BY(mu_) = false;
     PromiseEndpoint endpoint_;
-    HPackCompressor hpack_compressor_;
-    HPackParser hpack_parser_;
-    absl::BitGen bitgen_;
-    std::string connection_id_;
+    std::vector<std::string> connection_ids_;
     int32_t data_alignment_;
+    absl::BitGen bitgen_;
   };
 
   void Start(Server*, const std::vector<grpc_pollset*>*) override {
