@@ -16,6 +16,10 @@
 //
 //
 
+#include <grpc/event_engine/event_engine.h>
+#include <grpc/slice_buffer.h>
+#include <grpc/support/port_platform.h>
+#include <grpc/support/time.h>
 #include <inttypes.h>
 #include <stddef.h>
 
@@ -30,13 +34,8 @@
 #include "absl/log/log.h"
 #include "absl/status/status.h"
 #include "absl/types/optional.h"
-
-#include <grpc/event_engine/event_engine.h>
-#include <grpc/slice_buffer.h>
-#include <grpc/support/port_platform.h>
-#include <grpc/support/time.h>
-
 #include "src/core/channelz/channelz.h"
+#include "src/core/ext/transport/chttp2/transport/call_tracer_wrapper.h"
 #include "src/core/ext/transport/chttp2/transport/chttp2_transport.h"
 #include "src/core/ext/transport/chttp2/transport/context_list_entry.h"
 #include "src/core/ext/transport/chttp2/transport/flow_control.h"
@@ -49,16 +48,12 @@
 #include "src/core/ext/transport/chttp2/transport/http2_settings.h"
 #include "src/core/ext/transport/chttp2/transport/internal.h"
 #include "src/core/ext/transport/chttp2/transport/legacy_frame.h"
-#include "src/core/ext/transport/chttp2/transport/max_concurrent_streams_policy.h"
 #include "src/core/ext/transport/chttp2/transport/ping_callbacks.h"
 #include "src/core/ext/transport/chttp2/transport/ping_rate_policy.h"
+#include "src/core/ext/transport/chttp2/transport/stream_lists.h"
 #include "src/core/ext/transport/chttp2/transport/write_size_policy.h"
 #include "src/core/lib/debug/trace.h"
 #include "src/core/lib/experiments/experiments.h"
-#include "src/core/lib/gprpp/match.h"
-#include "src/core/lib/gprpp/ref_counted.h"
-#include "src/core/lib/gprpp/ref_counted_ptr.h"
-#include "src/core/lib/gprpp/time.h"
 #include "src/core/lib/iomgr/endpoint.h"
 #include "src/core/lib/iomgr/error.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
@@ -71,9 +66,13 @@
 #include "src/core/telemetry/call_tracer.h"
 #include "src/core/telemetry/stats.h"
 #include "src/core/telemetry/stats_data.h"
+#include "src/core/util/match.h"
+#include "src/core/util/ref_counted.h"
+#include "src/core/util/ref_counted_ptr.h"
+#include "src/core/util/time.h"
 #include "src/core/util/useful.h"
 
-// IWYU pragma: no_include "src/core/lib/gprpp/orphanable.h"
+// IWYU pragma: no_include "src/core/util/orphanable.h"
 
 static void add_to_write_list(grpc_chttp2_write_cb** list,
                               grpc_chttp2_write_cb* cb) {
@@ -205,24 +204,21 @@ static bool update_list(grpc_chttp2_transport* t, int64_t send_bytes,
 
 static void report_stall(grpc_chttp2_transport* t, grpc_chttp2_stream* s,
                          const char* staller) {
-  if (GRPC_TRACE_FLAG_ENABLED(flowctl)) {
-    VLOG(2) << t->peer_string.as_string_view() << ":" << t << " stream "
-            << s->id << " moved to stalled list by " << staller
-            << ". This is FULLY expected to happen in a healthy program that "
-               "is not seeing flow control stalls. However, if you know that "
-               "there are unwanted stalls, here is some helpful data: "
-               "[fc:pending="
-            << s->flow_controlled_buffer.length
-            << ":flowed=" << s->flow_controlled_bytes_flowed
-            << ":peer_initwin=" << t->settings.acked().initial_window_size()
-            << ":t_win=" << t->flow_control.remote_window() << ":s_win="
-            << static_cast<uint32_t>(
-                   std::max(int64_t{0},
-                            s->flow_control.remote_window_delta() +
-                                static_cast<int64_t>(
-                                    t->settings.peer().initial_window_size())))
-            << ":s_delta=" << s->flow_control.remote_window_delta() << "]";
-  }
+  GRPC_TRACE_VLOG(flowctl, 2)
+      << t->peer_string.as_string_view() << ":" << t << " stream " << s->id
+      << " moved to stalled list by " << staller
+      << ". This is FULLY expected to happen in a healthy program that is not "
+         "seeing flow control stalls. However, if you know that there are "
+         "unwanted stalls, here is some helpful data: [fc:pending="
+      << s->flow_controlled_buffer.length
+      << ":flowed=" << s->flow_controlled_bytes_flowed
+      << ":peer_initwin=" << t->settings.acked().initial_window_size()
+      << ":t_win=" << t->flow_control.remote_window() << ":s_win="
+      << static_cast<uint32_t>(std::max(
+             int64_t{0}, s->flow_control.remote_window_delta() +
+                             static_cast<int64_t>(
+                                 t->settings.peer().initial_window_size())))
+      << ":s_delta=" << s->flow_control.remote_window_delta() << "]";
 }
 
 namespace {
@@ -260,8 +256,6 @@ class WriteContext {
   }
 
   void FlushSettings() {
-    t_->settings.mutable_local().SetMaxConcurrentStreams(
-        t_->max_concurrent_streams_policy.AdvertiseValue());
     auto update = t_->settings.MaybeSendUpdate();
     if (update.has_value()) {
       grpc_core::Http2Frame frame(std::move(*update));
@@ -280,7 +274,6 @@ class WriteContext {
             });
       }
       t_->flow_control.FlushedSettings();
-      t_->max_concurrent_streams_policy.FlushedSettings();
       grpc_core::global_stats().IncrementHttp2SettingsWrites();
     }
   }
@@ -677,6 +670,8 @@ class StreamWriteContext {
 
 grpc_chttp2_begin_write_result grpc_chttp2_begin_write(
     grpc_chttp2_transport* t) {
+  GRPC_LATENT_SEE_INNER_SCOPE("grpc_chttp2_begin_write");
+
   int64_t outbuf_relative_start_pos = 0;
   WriteContext ctx(t);
   ctx.FlushSettings();
@@ -732,12 +727,17 @@ grpc_chttp2_begin_write_result grpc_chttp2_begin_write(
 
   maybe_initiate_ping(t);
 
+  t->write_flow.Begin(GRPC_LATENT_SEE_METADATA("write"));
+
   return ctx.Result();
 }
 
 void grpc_chttp2_end_write(grpc_chttp2_transport* t, grpc_error_handle error) {
+  GRPC_LATENT_SEE_INNER_SCOPE("grpc_chttp2_end_write");
   grpc_chttp2_stream* s;
 
+  t->write_flow.End();
+
   if (t->channelz_socket != nullptr) {
     t->channelz_socket->RecordMessagesSent(t->num_messages_in_next_write);
   }
