@@ -21,12 +21,11 @@
 #include "absl/log/check.h"
 #include "absl/strings/str_cat.h"
 #include "absl/strings/str_format.h"
-
 #include "src/core/lib/address_utils/parse_address.h"
 #include "src/core/lib/event_engine/cf_engine/dns_service_resolver.h"
 #include "src/core/lib/event_engine/posix_engine/lockfree_event.h"
 #include "src/core/lib/event_engine/tcp_socket_utils.h"
-#include "src/core/lib/gprpp/host_port.h"
+#include "src/core/util/host_port.h"
 
 namespace grpc_event_engine {
 namespace experimental {
@@ -43,7 +42,7 @@ void DNSServiceResolverImpl::LookupHostname(
   if (!grpc_core::SplitHostPort(name, &host, &port_string)) {
     engine_->Run([on_resolve = std::move(on_resolve),
                   status = absl::InvalidArgumentError(
-                      absl::StrCat("Unparseable name: ", name))]() mutable {
+                      absl::StrCat("Unparsable name: ", name))]() mutable {
       on_resolve(status);
     });
     return;
@@ -144,7 +143,7 @@ void DNSServiceResolverImpl::ResolveCallback(
       << ", this: " << context;
 
   // no need to increase refcount here, since ResolveCallback and Shutdown is
-  // called from the serial queue and it is guarenteed that it won't be called
+  // called from the serial queue and it is guaranteed that it won't be called
   // after the sdRef is deallocated
   auto that = static_cast<DNSServiceResolverImpl*>(context);
 
@@ -222,8 +221,12 @@ void DNSServiceResolverImpl::Shutdown() {
   dispatch_async_f(queue_, Ref().release(), [](void* thatPtr) {
     grpc_core::RefCountedPtr<DNSServiceResolverImpl> that{
         static_cast<DNSServiceResolverImpl*>(thatPtr)};
-    grpc_core::MutexLock lock(&that->request_mu_);
-    for (auto& kv : that->requests_) {
+
+    grpc_core::ReleasableMutexLock lock(&that->request_mu_);
+    auto requests = std::exchange(that->requests_, {});
+    lock.Release();
+
+    for (auto& kv : requests) {
       auto& sdRef = kv.first;
       auto& request = kv.second;
       GRPC_TRACE_LOG(event_engine_dns, INFO)
@@ -233,7 +236,6 @@ void DNSServiceResolverImpl::Shutdown() {
           absl::CancelledError("DNSServiceResolverImpl::Shutdown"));
       DNSServiceRefDeallocate(static_cast<DNSServiceRef>(sdRef));
     }
-    that->requests_.clear();
   });
 }
 
