@@ -16,21 +16,20 @@
 
 #include "src/core/server/server_call_tracer_filter.h"
 
+#include <grpc/support/port_platform.h>
+
 #include <functional>
 #include <memory>
 #include <utility>
 
 #include "absl/status/status.h"
 #include "absl/status/statusor.h"
-
-#include <grpc/support/port_platform.h>
-
+#include "src/core/config/core_configuration.h"
 #include "src/core/lib/channel/call_finalization.h"
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/channel/channel_fwd.h"
 #include "src/core/lib/channel/channel_stack.h"
 #include "src/core/lib/channel/promise_based_filter.h"
-#include "src/core/lib/config/core_configuration.h"
 #include "src/core/lib/promise/arena_promise.h"
 #include "src/core/lib/promise/cancel_callback.h"
 #include "src/core/lib/promise/context.h"
@@ -39,6 +38,7 @@
 #include "src/core/lib/surface/channel_stack_type.h"
 #include "src/core/lib/transport/transport.h"
 #include "src/core/telemetry/call_tracer.h"
+#include "src/core/util/latent_see.h"
 
 namespace grpc_core {
 
@@ -57,24 +57,31 @@ class ServerCallTracerFilter
   class Call {
    public:
     void OnClientInitialMetadata(ClientMetadata& client_initial_metadata) {
+      GRPC_LATENT_SEE_INNER_SCOPE(
+          "ServerCallTracerFilter::Call::OnClientInitialMetadata");
       auto* call_tracer = MaybeGetContext<ServerCallTracer>();
       if (call_tracer == nullptr) return;
       call_tracer->RecordReceivedInitialMetadata(&client_initial_metadata);
     }
 
     void OnServerInitialMetadata(ServerMetadata& server_initial_metadata) {
+      GRPC_LATENT_SEE_INNER_SCOPE(
+          "ServerCallTracerFilter::Call::OnServerInitialMetadata");
       auto* call_tracer = MaybeGetContext<ServerCallTracer>();
       if (call_tracer == nullptr) return;
       call_tracer->RecordSendInitialMetadata(&server_initial_metadata);
     }
 
     void OnFinalize(const grpc_call_final_info* final_info) {
+      GRPC_LATENT_SEE_INNER_SCOPE("ServerCallTracerFilter::Call::OnFinalize");
       auto* call_tracer = MaybeGetContext<ServerCallTracer>();
       if (call_tracer == nullptr) return;
       call_tracer->RecordEnd(final_info);
     }
 
     void OnServerTrailingMetadata(ServerMetadata& server_trailing_metadata) {
+      GRPC_LATENT_SEE_INNER_SCOPE(
+          "ServerCallTracerFilter::Call::OnServerTrailingMetadata");
       auto* call_tracer = MaybeGetContext<ServerCallTracer>();
       if (call_tracer == nullptr) return;
       call_tracer->RecordSendTrailingMetadata(&server_trailing_metadata);
