@@ -22,15 +22,13 @@
     !defined(GPR_CUSTOM_SYNC)
 
 #include <errno.h>
-#include <time.h>
-
-#include "absl/log/check.h"
-
 #include <grpc/support/alloc.h>
 #include <grpc/support/sync.h>
 #include <grpc/support/time.h>
+#include <time.h>
 
-#include "src/core/lib/gprpp/crash.h"
+#include "absl/log/check.h"
+#include "src/core/util/crash.h"
 
 void gpr_mu_init(gpr_mu* mu) {
 #ifdef GRPC_ASAN_ENABLED
