@@ -21,11 +21,10 @@
 
 #include "absl/log/check.h"
 #include "absl/status/statusor.h"
-
 #include "src/core/lib/address_utils/sockaddr_utils.h"
 #include "src/core/lib/iomgr/resolve_address.h"
 #include "src/core/lib/iomgr/resolved_address.h"
-#include "src/core/lib/uri/uri_parser.h"
+#include "src/core/util/uri.h"
 
 bool squelch = true;
 
