@@ -22,9 +22,9 @@
 #include "absl/log/log.h"
 #include "absl/strings/string_view.h"
 #include "gtest/gtest.h"
+#include "src/core/config/core_configuration.h"
 #include "src/core/lib/address_utils/parse_address.h"
 #include "src/core/lib/channel/promise_based_filter.h"
-#include "src/core/lib/config/core_configuration.h"
 #include "src/core/service_config/service_config_impl.h"
 #include "test/core/call/yodel/yodel_test.h"
 
@@ -274,11 +274,9 @@ CLIENT_CHANNEL_TEST(StartCall) {
   QueueNameResolutionResult(
       MakeSuccessfulResolutionResult("ipv4:127.0.0.1:1234"));
   auto call_handler = TickUntilCallStarted();
-  SpawnTestSeq(call.initiator, "cancel",
-               [call_initiator = call.initiator]() mutable {
-                 call_initiator.Cancel();
-                 return Empty{};
-               });
+  SpawnTestSeq(
+      call.initiator, "cancel",
+      [call_initiator = call.initiator]() mutable { call_initiator.Cancel(); });
   WaitForAllPendingWork();
 }
 
@@ -361,13 +359,10 @@ CLIENT_CHANNEL_TEST(ConfigSelectorWithDynamicFilters) {
           EXPECT_TRUE(value.has_value());
           if (value.has_value()) EXPECT_EQ(*value, "bar");
         }
-        return Empty{};
       });
-  SpawnTestSeq(call.initiator, "cancel",
-               [call_initiator = call.initiator]() mutable {
-                 call_initiator.Cancel();
-                 return Empty{};
-               });
+  SpawnTestSeq(
+      call.initiator, "cancel",
+      [call_initiator = call.initiator]() mutable { call_initiator.Cancel(); });
   WaitForAllPendingWork();
 }
 
