@@ -166,12 +166,8 @@ LOAD_BALANCED_CALL_DESTINATION_TEST(CreateCall) {
       call.initiator, "initiator",
       [this, handler = std::move(call.handler)]() {
         destination_under_test().StartCall(handler);
-        return Empty{};
       },
-      [call_initiator = call.initiator]() mutable {
-        call_initiator.Cancel();
-        return Empty{};
-      });
+      [call_initiator = call.initiator]() mutable { call_initiator.Cancel(); });
   WaitForAllPendingWork();
 }
 
@@ -180,7 +176,6 @@ LOAD_BALANCED_CALL_DESTINATION_TEST(StartCall) {
   SpawnTestSeq(call.initiator, "initiator",
                [this, handler = std::move(call.handler)]() {
                  destination_under_test().StartCall(handler);
-                 return Empty{};
                });
   auto mock_picker = MakeRefCounted<StrictMock<MockPicker>>();
   EXPECT_CALL(*mock_picker, Pick)
@@ -189,11 +184,9 @@ LOAD_BALANCED_CALL_DESTINATION_TEST(StartCall) {
       });
   picker().Set(mock_picker);
   auto handler = TickUntilCallStarted();
-  SpawnTestSeq(call.initiator, "cancel",
-               [call_initiator = call.initiator]() mutable {
-                 call_initiator.Cancel();
-                 return Empty{};
-               });
+  SpawnTestSeq(
+      call.initiator, "cancel",
+      [call_initiator = call.initiator]() mutable { call_initiator.Cancel(); });
   WaitForAllPendingWork();
 }
 
@@ -212,7 +205,6 @@ LOAD_BALANCED_CALL_DESTINATION_TEST(StartCallOnDestroyedChannel) {
       [](ServerMetadataHandle md) {
         EXPECT_EQ(md->get(GrpcStatusMetadata()).value_or(GRPC_STATUS_UNKNOWN),
                   GRPC_STATUS_UNAVAILABLE);
-        return Empty{};
       });
   // Set a picker and wait for at least one pick attempt to prove the call has
   // made it to the picker.
