@@ -31,7 +31,7 @@
 #include <grpc/compression.h>
 #include <grpc/grpc.h>
 
-#include "src/core/lib/config/core_configuration.h"
+#include "src/core/config/core_configuration.h"
 #include "src/core/lib/event_engine/default_event_engine.h"
 #include "src/core/util/no_destruct.h"
 #include "test/core/end2end/cq_verifier.h"
@@ -64,17 +64,15 @@ Slice RandomBinarySlice(size_t length) {
 void CoreEnd2endTest::SetUp() {
   CoreConfiguration::Reset();
   initialized_ = false;
+  grpc_prewarm_os_for_tests();
 }
 
 void CoreEnd2endTest::TearDown() {
   const bool do_shutdown = fixture_ != nullptr;
   std::shared_ptr<grpc_event_engine::experimental::EventEngine> ee;
-// TODO(hork): locate the windows leak so we can enable end2end experiments.
-#ifndef GPR_WINDOWS
   if (grpc_is_initialized()) {
     ee = grpc_event_engine::experimental::GetDefaultEventEngine();
   }
-#endif
   ShutdownAndDestroyClient();
   ShutdownAndDestroyServer();
   cq_verifier_.reset();
