@@ -19,8 +19,8 @@
 
 #include "absl/strings/string_view.h"
 #include "src/core/client_channel/subchannel_interface_internal.h"
+#include "src/core/config/core_configuration.h"
 #include "src/core/lib/address_utils/parse_address.h"
-#include "src/core/lib/config/core_configuration.h"
 #include "src/core/lib/event_engine/channel_args_endpoint_config.h"
 #include "src/core/lib/event_engine/default_event_engine.h"
 #include "src/core/lib/transport/connectivity_state.h"
@@ -32,7 +32,9 @@
 namespace grpc_core {
 namespace {
 
-bool IsSlowBuild() { return BuiltUnderMsan() || BuiltUnderUbsan(); }
+bool IsSlowBuild() {
+  return BuiltUnderMsan() || BuiltUnderUbsan() || BuiltUnderTsan();
+}
 
 class BenchmarkHelper : public std::enable_shared_from_this<BenchmarkHelper> {
  public:
