@@ -16,16 +16,14 @@
 //
 //
 
-#include <stdio.h>
-#include <string.h>
-
 #include <grpc/credentials.h>
 #include <grpc/slice.h>
 #include <grpc/support/alloc.h>
-#include <grpc/support/log.h>
+#include <stdio.h>
+#include <string.h>
 
-#include "src/core/lib/gprpp/crash.h"
 #include "src/core/lib/security/credentials/jwt/jwt_credentials.h"
+#include "src/core/util/crash.h"
 #include "test/core/test_util/cmdline.h"
 #include "test/core/test_util/tls_utils.h"
 
