@@ -73,14 +73,11 @@ class ForwardCallFixture {
           [p1_handler, &p2](ValueOrFailure<ClientMetadataHandle> md) mutable {
             CHECK(md.ok());
             ForwardCall(std::move(p1_handler), std::move(p2.initiator));
-            return Empty{};
           });
     });
     absl::optional<CallHandler> p2_handler;
-    p2.handler.SpawnInfallible("start", [&]() {
-      p2_handler = p2.handler.StartCall();
-      return Empty{};
-    });
+    p2.handler.SpawnInfallible("start",
+                               [&]() { p2_handler = p2.handler.StartCall(); });
     return {std::move(p1.initiator), std::move(*p2_handler)};
   }
 
