@@ -34,8 +34,8 @@
 #include "absl/types/optional.h"
 #include "gmock/gmock.h"
 #include "gtest/gtest.h"
+#include "src/core/config/core_configuration.h"
 #include "src/core/ext/transport/chaotic_good/client_transport.h"
-#include "src/core/lib/config/core_configuration.h"
 #include "src/core/lib/event_engine/event_engine_context.h"
 #include "src/core/lib/iomgr/timer_manager.h"
 #include "src/core/lib/promise/activity.h"
@@ -186,8 +186,8 @@ TEST_F(ClientTransportTest, AddOneStreamWithWriteFailed) {
   EXPECT_CALL(*control_endpoint.endpoint, Read).WillOnce(Return(false));
   auto transport = MakeOrphanable<ChaoticGoodClientTransport>(
       std::move(control_endpoint.promise_endpoint),
-      std::move(data_endpoint.promise_endpoint), MakeChannelArgs(),
-      event_engine(), HPackParser(), HPackCompressor());
+      OneDataEndpoint(std::move(data_endpoint.promise_endpoint)),
+      MakeChannelArgs(), event_engine());
   auto call = MakeCall(TestInitialMetadata());
   transport->StartCall(call.handler.StartCall());
   call.initiator.SpawnGuarded("test-send",
@@ -202,18 +202,18 @@ TEST_F(ClientTransportTest, AddOneStreamWithWriteFailed) {
             initiator.PullServerInitialMetadata(),
             [](ValueOrFailure<absl::optional<ServerMetadataHandle>> md) {
               EXPECT_TRUE(md.ok());
-              return Empty{};
             },
             initiator.PullServerTrailingMetadata(),
             [&on_done](ServerMetadataHandle md) {
               EXPECT_EQ(md->get(GrpcStatusMetadata()).value(),
                         GRPC_STATUS_UNAVAILABLE);
               on_done.Call();
-              return Empty{};
             });
       });
   // Wait until ClientTransport's internal activities to finish.
   event_engine()->TickUntilIdle();
+  transport.reset();
+  event_engine()->TickUntilIdle();
   event_engine()->UnsetGlobalHooks();
 }
 
@@ -230,8 +230,8 @@ TEST_F(ClientTransportTest, AddOneStreamWithReadFailed) {
           }));
   auto transport = MakeOrphanable<ChaoticGoodClientTransport>(
       std::move(control_endpoint.promise_endpoint),
-      std::move(data_endpoint.promise_endpoint), MakeChannelArgs(),
-      event_engine(), HPackParser(), HPackCompressor());
+      OneDataEndpoint(std::move(data_endpoint.promise_endpoint)),
+      MakeChannelArgs(), event_engine());
   auto call = MakeCall(TestInitialMetadata());
   transport->StartCall(call.handler.StartCall());
   call.initiator.SpawnGuarded("test-send",
@@ -246,18 +246,18 @@ TEST_F(ClientTransportTest, AddOneStreamWithReadFailed) {
             initiator.PullServerInitialMetadata(),
             [](ValueOrFailure<absl::optional<ServerMetadataHandle>> md) {
               EXPECT_TRUE(md.ok());
-              return Empty{};
             },
             initiator.PullServerTrailingMetadata(),
             [&on_done](ServerMetadataHandle md) {
               EXPECT_EQ(md->get(GrpcStatusMetadata()).value(),
                         GRPC_STATUS_UNAVAILABLE);
               on_done.Call();
-              return Empty{};
             });
       });
   // Wait until ClientTransport's internal activities to finish.
   event_engine()->TickUntilIdle();
+  transport.reset();
+  event_engine()->TickUntilIdle();
   event_engine()->UnsetGlobalHooks();
 }
 
@@ -282,8 +282,8 @@ TEST_F(ClientTransportTest, AddMultipleStreamWithWriteFailed) {
   EXPECT_CALL(*control_endpoint.endpoint, Read).WillOnce(Return(false));
   auto transport = MakeOrphanable<ChaoticGoodClientTransport>(
       std::move(control_endpoint.promise_endpoint),
-      std::move(data_endpoint.promise_endpoint), MakeChannelArgs(),
-      event_engine(), HPackParser(), HPackCompressor());
+      OneDataEndpoint(std::move(data_endpoint.promise_endpoint)),
+      MakeChannelArgs(), event_engine());
   auto call1 = MakeCall(TestInitialMetadata());
   transport->StartCall(call1.handler.StartCall());
   auto call2 = MakeCall(TestInitialMetadata());
@@ -306,14 +306,12 @@ TEST_F(ClientTransportTest, AddMultipleStreamWithWriteFailed) {
             initiator.PullServerInitialMetadata(),
             [](ValueOrFailure<absl::optional<ServerMetadataHandle>> md) {
               EXPECT_TRUE(md.ok());
-              return Empty{};
             },
             initiator.PullServerTrailingMetadata(),
             [&on_done1](ServerMetadataHandle md) {
               EXPECT_EQ(md->get(GrpcStatusMetadata()).value(),
                         GRPC_STATUS_UNAVAILABLE);
               on_done1.Call();
-              return Empty{};
             });
       });
   call2.initiator.SpawnInfallible(
@@ -322,18 +320,18 @@ TEST_F(ClientTransportTest, AddMultipleStreamWithWriteFailed) {
             initiator.PullServerInitialMetadata(),
             [](ValueOrFailure<absl::optional<ServerMetadataHandle>> md) {
               EXPECT_TRUE(md.ok());
-              return Empty{};
             },
             initiator.PullServerTrailingMetadata(),
             [&on_done2](ServerMetadataHandle md) {
               EXPECT_EQ(md->get(GrpcStatusMetadata()).value(),
                         GRPC_STATUS_UNAVAILABLE);
               on_done2.Call();
-              return Empty{};
             });
       });
   // Wait until ClientTransport's internal activities to finish.
   event_engine()->TickUntilIdle();
+  transport.reset();
+  event_engine()->TickUntilIdle();
   event_engine()->UnsetGlobalHooks();
 }
 
@@ -350,8 +348,8 @@ TEST_F(ClientTransportTest, AddMultipleStreamWithReadFailed) {
           }));
   auto transport = MakeOrphanable<ChaoticGoodClientTransport>(
       std::move(control_endpoint.promise_endpoint),
-      std::move(data_endpoint.promise_endpoint), MakeChannelArgs(),
-      event_engine(), HPackParser(), HPackCompressor());
+      OneDataEndpoint(std::move(data_endpoint.promise_endpoint)),
+      MakeChannelArgs(), event_engine());
   auto call1 = MakeCall(TestInitialMetadata());
   transport->StartCall(call1.handler.StartCall());
   auto call2 = MakeCall(TestInitialMetadata());
@@ -374,14 +372,12 @@ TEST_F(ClientTransportTest, AddMultipleStreamWithReadFailed) {
             initiator.PullServerInitialMetadata(),
             [](ValueOrFailure<absl::optional<ServerMetadataHandle>> md) {
               EXPECT_TRUE(md.ok());
-              return Empty{};
             },
             initiator.PullServerTrailingMetadata(),
             [&on_done1](ServerMetadataHandle md) {
               EXPECT_EQ(md->get(GrpcStatusMetadata()).value(),
                         GRPC_STATUS_UNAVAILABLE);
               on_done1.Call();
-              return Empty{};
             });
       });
   call2.initiator.SpawnInfallible(
@@ -390,18 +386,18 @@ TEST_F(ClientTransportTest, AddMultipleStreamWithReadFailed) {
             initiator.PullServerInitialMetadata(),
             [](ValueOrFailure<absl::optional<ServerMetadataHandle>> md) {
               EXPECT_TRUE(md.ok());
-              return Empty{};
             },
             initiator.PullServerTrailingMetadata(),
             [&on_done2](ServerMetadataHandle md) {
               EXPECT_EQ(md->get(GrpcStatusMetadata()).value(),
                         GRPC_STATUS_UNAVAILABLE);
               on_done2.Call();
-              return Empty{};
             });
       });
   // Wait until ClientTransport's internal activities to finish.
   event_engine()->TickUntilIdle();
+  transport.reset();
+  event_engine()->TickUntilIdle();
   event_engine()->UnsetGlobalHooks();
 }
 
