@@ -18,34 +18,30 @@
 
 #include "src/core/xds/grpc/xds_audit_logger_registry.h"
 
+#include <google/protobuf/any.pb.h>
+#include <grpc/grpc.h>
+#include <grpc/grpc_audit_logging.h>
+
 #include <memory>
 #include <string>
 
-#include <google/protobuf/any.pb.h>
-
 #include "absl/status/status.h"
 #include "absl/status/statusor.h"
 #include "absl/strings/str_format.h"
 #include "absl/strings/string_view.h"
-#include "envoy/config/rbac/v3/rbac.upb.h"
+#include "envoy/config/rbac/v3/rbac.pb.h"
+#include "envoy/extensions/rbac/audit_loggers/stream/v3/stream.pb.h"
 #include "google/protobuf/struct.pb.h"
 #include "gtest/gtest.h"
-#include "upb/mem/arena.hpp"
-#include "upb/reflection/def.hpp"
-
-#include <grpc/grpc.h>
-#include <grpc/grpc_audit_logging.h>
-
-#include "src/core/lib/gprpp/crash.h"
 #include "src/core/lib/security/authorization/audit_logging.h"
+#include "src/core/util/crash.h"
 #include "src/core/util/json/json.h"
 #include "src/core/util/json/json_writer.h"
 #include "src/core/xds/grpc/xds_bootstrap_grpc.h"
-#include "src/proto/grpc/testing/xds/v3/audit_logger_stream.pb.h"
-#include "src/proto/grpc/testing/xds/v3/extension.pb.h"
-#include "src/proto/grpc/testing/xds/v3/rbac.pb.h"
-#include "src/proto/grpc/testing/xds/v3/typed_struct.pb.h"
 #include "test/core/test_util/test_config.h"
+#include "upb/mem/arena.hpp"
+#include "upb/reflection/def.hpp"
+#include "xds/type/v3/typed_struct.pb.h"
 
 namespace grpc_core {
 namespace testing {
