@@ -28,7 +28,7 @@
 #include "opentelemetry/metrics/provider.h"
 #include "opentelemetry/sdk/metrics/meter_provider.h"
 #include "opentelemetry/sdk/metrics/metric_reader.h"
-#include "src/core/lib/config/core_configuration.h"
+#include "src/core/config/core_configuration.h"
 #include "src/core/telemetry/call_tracer.h"
 #include "src/core/util/env.h"
 #include "src/core/util/tmpfile.h"
