@@ -16,6 +16,9 @@
 //
 //
 
+#include <grpc++/grpc++.h>
+#include <grpcpp/support/status.h>
+
 #include <chrono>
 #include <thread>  // NOLINT
 
@@ -24,13 +27,9 @@
 #include "gmock/gmock.h"
 #include "google/protobuf/text_format.h"
 #include "gtest/gtest.h"
-
-#include <grpc++/grpc++.h>
-#include <grpcpp/support/status.h>
-
 #include "src/core/ext/filters/logging/logging_filter.h"
-#include "src/core/lib/gprpp/dump_args.h"
-#include "src/core/lib/gprpp/sync.h"
+#include "src/core/util/dump_args.h"
+#include "src/core/util/sync.h"
 #include "src/cpp/ext/gcp/observability_logging_sink.h"
 #include "src/proto/grpc/testing/echo.grpc.pb.h"
 #include "src/proto/grpc/testing/echo_messages.pb.h"
@@ -63,7 +62,7 @@ TEST_F(LoggingTest, SimpleRpc) {
   context.AddMetadata("key", "value");
   grpc::Status status = stub_->Echo(&context, request, &response);
   EXPECT_TRUE(status.ok());
-  g_test_logging_sink->WaitForNumEntries(12, absl::Seconds(5));
+  ASSERT_TRUE(g_test_logging_sink->WaitForNumEntries(12, absl::Seconds(5)));
   EXPECT_THAT(
       g_test_logging_sink->entries(),
       ::testing::UnorderedElementsAre(
@@ -247,7 +246,7 @@ TEST_F(LoggingTest, SimpleRpcNoMetadata) {
   grpc::ClientContext context;
   grpc::Status status = stub_->Echo(&context, request, &response);
   EXPECT_TRUE(status.ok());
-  g_test_logging_sink->WaitForNumEntries(12, absl::Seconds(5));
+  ASSERT_TRUE(g_test_logging_sink->WaitForNumEntries(12, absl::Seconds(5)));
   EXPECT_THAT(
       g_test_logging_sink->entries(),
       ::testing::UnorderedElementsAre(
@@ -448,7 +447,7 @@ TEST_F(LoggingTest, MetadataTruncated) {
   context.AddMetadata("key-2", "value-2");
   grpc::Status status = stub_->Echo(&context, request, &response);
   EXPECT_TRUE(status.ok());
-  g_test_logging_sink->WaitForNumEntries(12, absl::Seconds(5));
+  ASSERT_TRUE(g_test_logging_sink->WaitForNumEntries(12, absl::Seconds(5)));
   EXPECT_THAT(
       g_test_logging_sink->entries(),
       ::testing::UnorderedElementsAre(
@@ -631,7 +630,7 @@ TEST_F(LoggingTest, PayloadTruncated) {
   grpc::ClientContext context;
   grpc::Status status = stub_->Echo(&context, request, &response);
   EXPECT_TRUE(status.ok());
-  g_test_logging_sink->WaitForNumEntries(12, absl::Seconds(5));
+  ASSERT_TRUE(g_test_logging_sink->WaitForNumEntries(12, absl::Seconds(5)));
   EXPECT_THAT(
       g_test_logging_sink->entries(),
       ::testing::UnorderedElementsAre(
@@ -862,7 +861,7 @@ TEST_F(LoggingTest, ServerCancelsRpc) {
   EXPECT_EQ(status.error_code(), 25);
   EXPECT_EQ(status.error_message(), "error message");
   EXPECT_EQ(status.error_details(), "binary error details");
-  g_test_logging_sink->WaitForNumEntries(9, absl::Seconds(5));
+  ASSERT_TRUE(g_test_logging_sink->WaitForNumEntries(9, absl::Seconds(5)));
   EXPECT_THAT(
       g_test_logging_sink->entries(),
       ::testing::UnorderedElementsAre(
